"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const prettyMilliseconds = require("pretty-ms");
const core_1 = require("@kui-shell/core");
const opts_1 = require("../opts");
const apiVersion_1 = require("../apiVersion");
const exec_1 = require("../exec");
const command_prefix_1 = require("../command-prefix");
const cluster_1 = require("../../models/cluster");
const strings = core_1.i18n('plugin-ibmcloud/ks');
function prettyPrintDuration(delta) {
    return prettyMilliseconds(delta, { compact: true });
}
function workerSummary(content) {
    const nWorkers = content.workerCount;
    const nZones = content.workerZones.length;
    if (nWorkers === 1 && nZones === 1) {
        return strings('one worker in zone', ...content.workerZones, content.location);
    }
    else if (nWorkers === 1) {
        return strings('one worker in zonez', ...content.workerZones, content.location);
    }
    else if (nZones === 1) {
        return strings('N workers in zone', content.workerCount, ...content.workerZones, content.location);
    }
    else {
        return strings('N workers in zones', content.workerCount, ...content.workerZones, content.location);
    }
}
function doGet(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const { safeDump } = yield Promise.resolve().then(() => require('js-yaml'));
        const content = JSON.parse(yield exec_1.default(args));
        const toolbarText = cluster_1.hasAvailableUpdates(content)
            ? {
                type: 'warning',
                text: strings('An update is available for the cluster')
            }
            : undefined;
        const updateSummary = cluster_1.hasAvailableUpdates(content)
            ? {
                'Available Update': `${content.masterKubeVersion} \u2192 ${content.targetVersion}`
            }
            : {};
        return {
            apiVersion: apiVersion_1.default,
            kind: 'Cluster',
            metadata: {
                name: content.name,
                namespace: content.resourceGroupName,
                creationTimestamp: content.createdDate
            },
            nameHash: content.id,
            toolbarText,
            data: safeDump(content),
            version: content.masterKubeVersion,
            modes: [],
            content,
            isSimulacrum: true,
            summary: {
                content: safeDump(Object.assign({
                    Age: prettyPrintDuration(new Date().getTime() - new Date(content.createdDate).getTime()),
                    'Last Modified': strings('ago', prettyPrintDuration(new Date().getTime() - new Date(content.modifiedDate).getTime())),
                    Workers: workerSummary(content),
                    'Ingress Hostname': content.ingressHostname
                }, updateSummary)),
                contentType: 'yaml'
            }
        };
    });
}
exports.default = (registrar) => {
    registrar.listen(`/${command_prefix_1.default}/ibmcloud/ks/cluster/get`, doGet, opts_1.default);
};
//# sourceMappingURL=get.js.map