"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@kui-shell/core");
const opts_1 = require("../opts");
const apiVersion_1 = require("../apiVersion");
const exec_1 = require("../exec");
const command_prefix_1 = require("../command-prefix");
const worker_1 = require("../../models/worker");
const strings = core_1.i18n('plugin-ibmcloud/ks');
const idPattern = /[^-]+-[^-]+-([^-]+)-([^-]+)/;
function parseWorkerName(id) {
    const [, nameHash, name] = id.match(idPattern);
    return { name, nameHash };
}
function doGet(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const { safeDump } = yield Promise.resolve().then(() => require('js-yaml'));
        const content = JSON.parse(yield exec_1.default(args));
        const toolbarText = worker_1.hasAvailableUpdates(content)
            ? {
                type: 'warning',
                text: strings('An update is available for this worker')
            }
            : undefined;
        const updateSummary = worker_1.hasAvailableUpdates(content)
            ? {
                'Available Update': `${content.kubeVersion} \u2192 ${content.targetVersion}`
            }
            : {};
        const { name, nameHash } = parseWorkerName(content.id);
        return {
            apiVersion: apiVersion_1.default,
            kind: 'Worker',
            metadata: {
                name: content.id,
                namespace: content.poolName
            },
            spec: {
                cluster: args.parsedOptions.cluster
            },
            prettyName: name,
            nameHash,
            toolbarText,
            data: safeDump(content),
            version: content.kubeVersion,
            modes: [],
            content,
            isSimulacrum: true,
            summary: {
                content: safeDump(Object.assign({
                    'Public IP': content.publicIP,
                    'Private IP': content.privateIP
                }, updateSummary)),
                contentType: 'yaml'
            }
        };
    });
}
exports.default = (registrar) => {
    registrar.listen(`/${command_prefix_1.default}/ibmcloud/ks/worker/get`, doGet, opts_1.default);
};
//# sourceMappingURL=get.js.map