import { ResourceWithMetadata } from '@kui-shell/core';
import { WithRawData, WithSummary } from '@kui-shell/plugin-kubeui';
import WithVersion from './version';
import WithCluster from './with-cluster';
import { ClusterState } from './cluster';
export declare type WorkerState = ClusterState;
export declare const enum WorkerStatus {
    Ready = 0
}
export declare const enum WorkerIsolation {
    public = 0
}
export interface IBMCloudWorkerRaw {
    privateVlan: string;
    publicVlan: string;
    privateIP: string;
    publicIP: string;
    machineType: string;
    location: string;
    id: string;
    state: WorkerState;
    status: WorkerStatus;
    statusDate: string;
    statusDetails: string;
    errorMessage: string;
    errorMessageDate: string;
    isolation: WorkerIsolation;
    kubeVersion: string;
    targetVersion: string;
    reasonForDelete: string;
    versionEOS: string;
    masterVersionEOS: string;
    trustedStatus: WorkerStatus;
    poolid: string;
    poolName: string;
    pendingOperation: string;
}
export declare type IBMCloudWorker = ResourceWithMetadata<IBMCloudWorkerRaw> & WithSummary & WithCluster<IBMCloudWorkerRaw> & WithRawData<IBMCloudWorkerRaw> & WithVersion<IBMCloudWorkerRaw> & {
    apiVersion: any;
    kind: 'Worker';
    isSimulacrum: true;
};
export declare function isIBMCloudWorker(resource: ResourceWithMetadata): resource is IBMCloudWorker;
export declare function hasAvailableUpdates(worker: IBMCloudWorkerRaw): boolean;
export declare function isIBMCloudWorkerWithAvailableUpdates(resource: ResourceWithMetadata): resource is IBMCloudWorker;
export default IBMCloudWorkerRaw;
