var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as prettyMilliseconds from 'pretty-ms';
import { i18n } from '@kui-shell/core';
import opts from '../opts';
import apiVersion from '../apiVersion';
import doJSONWithStdout from '../exec';
import commandPrefix from '../command-prefix';
import { hasAvailableUpdates } from '../../models/cluster';
const strings = i18n('plugin-ibmcloud/ks');
function prettyPrintDuration(delta) {
    return prettyMilliseconds(delta, { compact: true });
}
function workerSummary(content) {
    const nWorkers = content.workerCount;
    const nZones = content.workerZones.length;
    if (nWorkers === 1 && nZones === 1) {
        return strings('one worker in zone', ...content.workerZones, content.location);
    }
    else if (nWorkers === 1) {
        return strings('one worker in zonez', ...content.workerZones, content.location);
    }
    else if (nZones === 1) {
        return strings('N workers in zone', content.workerCount, ...content.workerZones, content.location);
    }
    else {
        return strings('N workers in zones', content.workerCount, ...content.workerZones, content.location);
    }
}
function doGet(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const { safeDump } = yield import('js-yaml');
        const content = JSON.parse(yield doJSONWithStdout(args));
        const toolbarText = hasAvailableUpdates(content)
            ? {
                type: 'warning',
                text: strings('An update is available for the cluster')
            }
            : undefined;
        const updateSummary = hasAvailableUpdates(content)
            ? {
                'Available Update': `${content.masterKubeVersion} \u2192 ${content.targetVersion}`
            }
            : {};
        return {
            apiVersion,
            kind: 'Cluster',
            metadata: {
                name: content.name,
                namespace: content.resourceGroupName,
                creationTimestamp: content.createdDate
            },
            nameHash: content.id,
            toolbarText,
            data: safeDump(content),
            version: content.masterKubeVersion,
            modes: [],
            content,
            isSimulacrum: true,
            summary: {
                content: safeDump(Object.assign({
                    Age: prettyPrintDuration(new Date().getTime() - new Date(content.createdDate).getTime()),
                    'Last Modified': strings('ago', prettyPrintDuration(new Date().getTime() - new Date(content.modifiedDate).getTime())),
                    Workers: workerSummary(content),
                    'Ingress Hostname': content.ingressHostname
                }, updateSummary)),
                contentType: 'yaml'
            }
        };
    });
}
export default (registrar) => {
    registrar.listen(`/${commandPrefix}/ibmcloud/ks/cluster/get`, doGet, opts);
};
//# sourceMappingURL=get.js.map