var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { i18n } from '@kui-shell/core';
import opts from '../opts';
import apiVersion from '../apiVersion';
import doJSONWithStdout from '../exec';
import commandPrefix from '../command-prefix';
import { hasAvailableUpdates } from '../../models/worker';
const strings = i18n('plugin-ibmcloud/ks');
const idPattern = /[^-]+-[^-]+-([^-]+)-([^-]+)/;
function parseWorkerName(id) {
    const [, nameHash, name] = id.match(idPattern);
    return { name, nameHash };
}
function doGet(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const { safeDump } = yield import('js-yaml');
        const content = JSON.parse(yield doJSONWithStdout(args));
        const toolbarText = hasAvailableUpdates(content)
            ? {
                type: 'warning',
                text: strings('An update is available for this worker')
            }
            : undefined;
        const updateSummary = hasAvailableUpdates(content)
            ? {
                'Available Update': `${content.kubeVersion} \u2192 ${content.targetVersion}`
            }
            : {};
        const { name, nameHash } = parseWorkerName(content.id);
        return {
            apiVersion,
            kind: 'Worker',
            metadata: {
                name: content.id,
                namespace: content.poolName
            },
            spec: {
                cluster: args.parsedOptions.cluster
            },
            prettyName: name,
            nameHash,
            toolbarText,
            data: safeDump(content),
            version: content.kubeVersion,
            modes: [],
            content,
            isSimulacrum: true,
            summary: {
                content: safeDump(Object.assign({
                    'Public IP': content.publicIP,
                    'Private IP': content.privateIP
                }, updateSummary)),
                contentType: 'yaml'
            }
        };
    });
}
export default (registrar) => {
    registrar.listen(`/${commandPrefix}/ibmcloud/ks/worker/get`, doGet, opts);
};
//# sourceMappingURL=get.js.map