import { ResourceWithMetadata } from '@kui-shell/core';
import { WithRawData, WithSummary } from '@kui-shell/plugin-kubeui';
import WithVersion from './version';
export declare const enum ClusterState {
    unsupported = 0,
    normal = 1,
    active = 2
}
export interface IBMCloudClusterRaw {
    location: string;
    dataCenter: string;
    multiAzCapable: boolean;
    workerZones: string[];
    id: string;
    name: string;
    region: string;
    resourceGroup: string;
    resourceGroupName: string;
    serverURL: string;
    state: string;
    createdDate: string;
    modifiedDate: string;
    workerCount: number;
    isPaid: boolean;
    masterKubeVersion: string;
    targetVersion: string;
    ingressHostname: string;
    ingressSecretName: string;
    ownerEmail: string;
    logOrg: string;
    logOrgName: string;
    logSpace: string;
    logSpaceName: string;
    apiUser: string;
    monitoringURL: string;
    versionEOS: string;
    disableAutoUpdate: boolean;
    etcdPort: number;
    masterStatus: string;
    masterStatusModifiedDate: string;
    masterHealth: string;
    masterState: ClusterState;
    keyProtectEnabled: boolean;
    pullSecretApplied: boolean;
    crn: string;
    privateServiceEndpointEnabled: boolean;
    privateServiceEndpointURL: string;
    publicServiceEndpointEnabled: boolean;
    publicServiceEndpointURL: string;
    podSubnet: string;
    serviceSubnet: string;
    type: string;
}
export declare type IBMCloudCluster = ResourceWithMetadata<IBMCloudClusterRaw> & WithSummary & WithVersion<IBMCloudClusterRaw> & WithRawData<IBMCloudClusterRaw> & {
    apiVersion: any;
    kind: 'Cluster';
    isSimulacrum: true;
};
export declare function isIBMCloudCluster(resource: ResourceWithMetadata): resource is IBMCloudCluster;
export declare function hasAvailableUpdates(cluster: IBMCloudClusterRaw): boolean;
export declare function isIBMCloudClusterWithAvailableUpdates(resource: ResourceWithMetadata): resource is IBMCloudCluster;
export default IBMCloudClusterRaw;
