"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const prettyMilliseconds = require("pretty-ms");
const ks_1 = require("@kui-shell/plugin-ibmcloud/ks");
const core_1 = require("@kui-shell/core");
const semver_1 = require("./semver");
const url_1 = require("./repo/url");
const apiVersion_1 = require("./apiVersion");
const deprecated_1 = require("./deprecated");
const available_1 = require("./available");
const installed_1 = require("./installed");
const trim_1 = require("./trim");
const strings = core_1.i18n('plugin-ibmcloud/plugin');
const ksStrings = core_1.i18n('plugin-ibmcloud/ks');
function prettyPrintDuration(delta) {
    return prettyMilliseconds(delta, { compact: true });
}
const doGet = (cmd) => (args) => __awaiter(void 0, void 0, void 0, function* () {
    const whichRepo = args.parsedOptions.r || args.parsedOptions.repo;
    const repoURL = whichRepo ? yield url_1.default(args, whichRepo) : undefined;
    const which = args.argvNoOptions[args.argvNoOptions.indexOf(cmd) + 1];
    const [{ Plugins: installed }, { plugins: available }, { safeDump }] = yield Promise.all([
        installed_1.default(args),
        available_1.default(args.tab, repoURL),
        Promise.resolve().then(() => require('js-yaml'))
    ]);
    const installedEntry = installed[which];
    const isInstalled = installedEntry !== undefined;
    const currentVersion = isInstalled ? semver_1.default(installedEntry.Version) : '';
    const availableEntry = available.find(_ => _.name === which);
    const latest = availableEntry && availableEntry.versions[availableEntry.versions.length - 1];
    const updateAvailable = isInstalled && latest && latest.version !== currentVersion;
    const toolbarText = updateAvailable
        ? {
            type: 'warning',
            text: strings('An update is available for this plugin')
        }
        : undefined;
    return {
        apiVersion: apiVersion_1.default,
        kind: 'Plugin',
        metadata: {
            name: which,
            namespace: availableEntry.company,
            creationTimestamp: availableEntry.updated
        },
        toolbarText,
        data: safeDump(isInstalled ? installedEntry : availableEntry),
        version: `v${isInstalled ? currentVersion : latest.version}`,
        modes: [
            {
                mode: 'Compatibility',
                content: safeDump({
                    'Plugin SDK Version': currentVersion || latest.version,
                    'Minimal IBM Cloud CLI version required': (isInstalled ? semver_1.default(installedEntry) : latest.min_cli_version) || strings('N/A')
                }),
                contentType: 'yaml'
            },
            {
                mode: 'Versions',
                content: {
                    header: {
                        name: strings('VERSION'),
                        attributes: [{ value: strings('RELEASE DATE') }]
                    },
                    body: availableEntry.versions.map(_ => ({
                        name: _.version,
                        attributes: [
                            {
                                key: 'RELEASE DATE',
                                value: ksStrings('ago', prettyPrintDuration(new Date().getTime() - new Date(_.updated).getTime()))
                            }
                        ]
                    }))
                }
            }
        ],
        content: installedEntry,
        isSimulacrum: true,
        spec: {
            updateAvailable,
            status: deprecated_1.isDeprecated(availableEntry)
                ? 'Deprecated'
                : isInstalled
                    ? updateAvailable
                        ? 'Update Available'
                        : 'Ready'
                    : 'Available'
        },
        summary: {
            content: `## ${strings('Description')}\n\n${trim_1.default(availableEntry.description) ||
                strings('N/A')}\n\n## Status\n\n- ${strings('Initially created', prettyPrintDuration(new Date().getTime() - new Date(availableEntry.created).getTime()))}\n\n- ${strings('Last updated', prettyPrintDuration(new Date().getTime() - new Date(availableEntry.updated).getTime()))}\n\n${deprecated_1.isDeprecated(availableEntry)
                ? '- <strong class="red-text">' + strings('This plugin has been deprecated') + '</strong>'
                : !updateAvailable
                    ? ''
                    : '- **' + strings('Available Update') + ': ' + currentVersion + ' \u2192 ' + latest.version + '**'}`,
            contentType: 'text/markdown'
        }
    };
});
exports.default = (registrar) => {
    const cmd = registrar.listen(`/${ks_1.commandPrefix}/ibmcloud/plugin/show`, doGet('show'), ks_1.opts);
    registrar.synonym(`/${ks_1.commandPrefix}/ibmcloud/plugin/get`, doGet('get'), cmd, ks_1.opts);
};
//# sourceMappingURL=get.js.map