"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ks_1 = require("@kui-shell/plugin-ibmcloud/ks");
const core_1 = require("@kui-shell/core");
const url_1 = require("./url");
const semver_1 = require("../semver");
const installed_1 = require("../installed");
const available_1 = require("../available");
const plugin_1 = require("../../models/plugin");
const deprecated_1 = require("../deprecated");
const strings = core_1.i18n('plugin-ibmcloud/plugin');
function doList(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const whichRepo = args.parsedOptions.r || args.parsedOptions.repo;
        const repoURL = whichRepo ? yield url_1.default(args, whichRepo) : undefined;
        const [{ Plugins: installedPlugins }, { plugins: availablePlugins }] = yield Promise.all([
            installed_1.default(args),
            available_1.getAvailablePluginsSafe(args.tab, repoURL)
        ]);
        const body = availablePlugins.map(availablePlugin => {
            const { name, description, versions } = availablePlugin;
            const isInstalled = installedPlugins[name] !== undefined;
            const installedVersion = isInstalled ? semver_1.default(installedPlugins[name].Version) : '';
            const latestVersion = versions[versions.length - 1].version;
            const updateAvailable = isInstalled && installedVersion !== latestVersion;
            const isItDeprecated = deprecated_1.isDeprecated(availablePlugin);
            const descriptionForDisplay = description.replace(deprecated_1.isDeprecatedPattern, '');
            const status = isItDeprecated
                ? 'Deprecated'
                : isInstalled
                    ? updateAvailable
                        ? 'Update Available'
                        : 'Ready'
                    : 'Available';
            return {
                name,
                onclick: `ibmcloud plugin repo-plugin ${args.REPL.encodeComponent(name)}${whichRepo ? ' -r ' + args.REPL.encodeComponent(whichRepo) : ''}`,
                onclickSilence: true,
                attributes: [
                    {
                        key: strings('STATUS'),
                        tag: 'badge',
                        value: strings(status),
                        css: plugin_1.trafficLight(status)
                    },
                    {
                        key: strings('DESCRIPTION'),
                        value: descriptionForDisplay,
                        outerCSS: 'hide-with-sidecar'
                    }
                ]
            };
        });
        const header = {
            name: 'NAME',
            attributes: body[0].attributes.map(_ => ({ value: _.key, outerCSS: _.outerCSS }))
        };
        return {
            header,
            body
        };
    });
}
exports.default = (registrar) => {
    const cmd = registrar.listen(`/${ks_1.commandPrefix}/ibmcloud/plugin/repo/available/list`, doList, ks_1.opts);
    registrar.synonym(`/${ks_1.commandPrefix}/ibmcloud/plugin/repo/available/ls`, doList, cmd, ks_1.opts);
    registrar.listen(`/${ks_1.commandPrefix}/ibmcloud/plugin/repo-plugins`, doList, ks_1.opts);
    registrar.listen(`/${ks_1.commandPrefix}/ibmcloud/plugin/repo-plugin`, (args) => {
        const pluginArg = args.REPL.encodeComponent(args.argvNoOptions[args.argvNoOptions.indexOf('repo-plugin') + 1]);
        const whichRepo = args.parsedOptions.r || args.parsedOptions.repo;
        const repoArg = whichRepo ? `-r ${args.REPL.encodeComponent(whichRepo)}` : '';
        const cmd = `${ks_1.commandPrefix} ibmcloud plugin get ${pluginArg} ${repoArg}`;
        return args.REPL.qexec(cmd);
    }, ks_1.opts);
};
//# sourceMappingURL=available.js.map