"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ks_1 = require("@kui-shell/plugin-ibmcloud/ks");
const core_1 = require("@kui-shell/core");
const url_1 = require("./url");
const raw_1 = require("./raw");
const apiVersion_1 = require("../apiVersion");
const available_1 = require("../available");
const installed_1 = require("../installed");
const strings = core_1.i18n('plugin-ibmcloud/plugin');
function doGet(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const idx = args.argvNoOptions.indexOf('get') + 1;
        const whichRepo = args.argvNoOptions[idx];
        const repoURL = yield url_1.default(args, whichRepo);
        const [installed, { Plugins: installedPlugins }, { plugins: availablePlugins }] = yield Promise.all([
            raw_1.default(args),
            installed_1.default(args),
            available_1.default(args.tab, repoURL)
        ]);
        const installedEntry = installed.find(_ => _.Name === whichRepo);
        const installedPluginsFromRepo = availablePlugins.filter(_ => installedPlugins[_.name] !== undefined);
        if (!installedEntry) {
            const err = new Error(strings('Repository not installed'));
            err.code = 404;
            throw err;
        }
        const toList = (L) => L.map(_ => _.name).join(' <strong class="sub-text">|</strong> ');
        const summary = `## ${strings('Installed Plugins')}\n${toList(installedPluginsFromRepo)}\n\n## ${strings('Available Plugins')}\n${toList(availablePlugins)}`;
        return {
            apiVersion: apiVersion_1.default,
            kind: 'Repository',
            isSimulacrum: true,
            metadata: {
                name: whichRepo
            },
            toolbarText: {
                type: 'info',
                text: strings('Home URL', installedEntry.URL)
            },
            modes: [],
            content: installedEntry,
            summary: {
                content: summary,
                contentType: 'text/markdown'
            }
        };
    });
}
exports.default = (registrar) => {
    registrar.listen(`/${ks_1.commandPrefix}/ibmcloud/plugin/repo/get`, doGet, ks_1.opts);
};
//# sourceMappingURL=get.js.map