var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { opts, commandPrefix } from '@kui-shell/plugin-ibmcloud/ks';
import { i18n } from '@kui-shell/core';
import apiVersion from '../apiVersion';
import getInstalledPlugins from '../installed';
const strings = i18n('plugin-ibmcloud/plugin');
function doGet(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const idx = args.argvNoOptions.indexOf('get') + 1;
        const whichPlugin = args.argvNoOptions[idx];
        const whichCommand = args.argvNoOptions[idx + 1];
        const whichNamespace = args.parsedOptions.namespace;
        const { Plugins: installed } = yield getInstalledPlugins(args);
        const installedEntry = installed[whichPlugin];
        if (!installedEntry) {
            const err = new Error(strings('Plugin not installed'));
            err.code = 404;
            throw err;
        }
        const installedCommand = installedEntry.Commands.find(_ => _.Name === whichCommand && (!whichNamespace || _.Namespace === whichNamespace));
        if (!installedCommand) {
            console.error('command not found', whichCommand, whichNamespace, installedEntry);
            const err = new Error(strings('Specified command not found in this plugin'));
            err.code = 404;
            throw err;
        }
        const firstNewlineOfUsage = installedCommand.Usage.indexOf('\n');
        const usageLine1 = installedCommand.Usage.substring(0, firstNewlineOfUsage === -1 ? installedCommand.Usage.length : firstNewlineOfUsage);
        const usageRest = firstNewlineOfUsage === -1 ? '' : `### Notes:\n\n> ${installedCommand.Usage.substring(firstNewlineOfUsage + 1)}`;
        const summary = `## Description\n\n${installedCommand.Description}\n\n## Usage\n\n\`\`\`\n${usageLine1}\n\`\`\`\n${usageRest}`;
        return {
            apiVersion,
            kind: 'Command',
            isSimulacrum: true,
            metadata: {
                name: whichCommand,
                namespace: whichNamespace
            },
            prettyName: `ibmcloud${installedCommand.Namespace ? ' ' + installedCommand.Namespace : ''} ${installedCommand.Name}`,
            toolbarText: {
                type: 'info',
                text: strings('This command is part of the plugin', installedEntry.Name)
            },
            modes: [],
            content: installedEntry,
            spec: {
                usage: installedCommand.Usage
            },
            summary: {
                content: summary,
                contentType: 'text/markdown'
            }
        };
    });
}
export default (registrar) => {
    registrar.listen(`/${commandPrefix}/ibmcloud/plugin/command/get`, doGet, opts);
};
//# sourceMappingURL=get.js.map