var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { opts, commandPrefix } from '@kui-shell/plugin-ibmcloud/ks';
import { i18n } from '@kui-shell/core';
import getInstalledPlugins from '../installed';
import trimSolitaryTrailingDots from '../trim';
const strings = i18n('plugin-ibmcloud/plugin');
function doList(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const which = args.argvNoOptions[args.argvNoOptions.indexOf('list') + 1];
        const { Plugins: installed } = yield getInstalledPlugins(args);
        const installedEntry = installed[which];
        if (!installedEntry) {
            const err = new Error(strings('Plugin not installed'));
            err.code = 404;
            throw err;
        }
        const body = installedEntry.Commands.map(_ => {
            const name = `ibmcloud${_.Namespace ? ' ' + _.Namespace : ''} ${_.Name}`;
            return {
                name,
                onclick: `ibmcloud plugin command get ${which} ${_.Name}${_.Namespace ? ' --namespace ' + args.REPL.encodeComponent(_.Namespace) : ''}`,
                onclickSilence: true,
                attributes: [
                    {
                        key: 'DESCRIPTION',
                        value: trimSolitaryTrailingDots(_.Description),
                        outerCSS: 'hide-with-sidecar',
                        css: 'pre-wrap'
                    }
                ]
            };
        });
        const header = {
            name: 'NAME',
            attributes: body[0].attributes.map(_ => ({ value: _.key, outerCSS: _.outerCSS }))
        };
        return {
            header,
            body
        };
    });
}
export default (registrar) => {
    registrar.listen(`/${commandPrefix}/ibmcloud/plugin/command/list`, doList, opts);
};
//# sourceMappingURL=list.js.map