var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as prettyMilliseconds from 'pretty-ms';
import { opts, commandPrefix } from '@kui-shell/plugin-ibmcloud/ks';
import { i18n } from '@kui-shell/core';
import semver from './semver';
import getRepoURL from './repo/url';
import apiVersion from './apiVersion';
import { isDeprecated } from './deprecated';
import getAvailablePlugins from './available';
import getInstalledPlugins from './installed';
import trimSolitaryTrailingDots from './trim';
const strings = i18n('plugin-ibmcloud/plugin');
const ksStrings = i18n('plugin-ibmcloud/ks');
function prettyPrintDuration(delta) {
    return prettyMilliseconds(delta, { compact: true });
}
const doGet = (cmd) => (args) => __awaiter(void 0, void 0, void 0, function* () {
    const whichRepo = args.parsedOptions.r || args.parsedOptions.repo;
    const repoURL = whichRepo ? yield getRepoURL(args, whichRepo) : undefined;
    const which = args.argvNoOptions[args.argvNoOptions.indexOf(cmd) + 1];
    const [{ Plugins: installed }, { plugins: available }, { safeDump }] = yield Promise.all([
        getInstalledPlugins(args),
        getAvailablePlugins(args.tab, repoURL),
        import('js-yaml')
    ]);
    const installedEntry = installed[which];
    const isInstalled = installedEntry !== undefined;
    const currentVersion = isInstalled ? semver(installedEntry.Version) : '';
    const availableEntry = available.find(_ => _.name === which);
    const latest = availableEntry && availableEntry.versions[availableEntry.versions.length - 1];
    const updateAvailable = isInstalled && latest && latest.version !== currentVersion;
    const toolbarText = updateAvailable
        ? {
            type: 'warning',
            text: strings('An update is available for this plugin')
        }
        : undefined;
    return {
        apiVersion,
        kind: 'Plugin',
        metadata: {
            name: which,
            namespace: availableEntry.company,
            creationTimestamp: availableEntry.updated
        },
        toolbarText,
        data: safeDump(isInstalled ? installedEntry : availableEntry),
        version: `v${isInstalled ? currentVersion : latest.version}`,
        modes: [
            {
                mode: 'Compatibility',
                content: safeDump({
                    'Plugin SDK Version': currentVersion || latest.version,
                    'Minimal IBM Cloud CLI version required': (isInstalled ? semver(installedEntry) : latest.min_cli_version) || strings('N/A')
                }),
                contentType: 'yaml'
            },
            {
                mode: 'Versions',
                content: {
                    header: {
                        name: strings('VERSION'),
                        attributes: [{ value: strings('RELEASE DATE') }]
                    },
                    body: availableEntry.versions.map(_ => ({
                        name: _.version,
                        attributes: [
                            {
                                key: 'RELEASE DATE',
                                value: ksStrings('ago', prettyPrintDuration(new Date().getTime() - new Date(_.updated).getTime()))
                            }
                        ]
                    }))
                }
            }
        ],
        content: installedEntry,
        isSimulacrum: true,
        spec: {
            updateAvailable,
            status: isDeprecated(availableEntry)
                ? 'Deprecated'
                : isInstalled
                    ? updateAvailable
                        ? 'Update Available'
                        : 'Ready'
                    : 'Available'
        },
        summary: {
            content: `## ${strings('Description')}\n\n${trimSolitaryTrailingDots(availableEntry.description) ||
                strings('N/A')}\n\n## Status\n\n- ${strings('Initially created', prettyPrintDuration(new Date().getTime() - new Date(availableEntry.created).getTime()))}\n\n- ${strings('Last updated', prettyPrintDuration(new Date().getTime() - new Date(availableEntry.updated).getTime()))}\n\n${isDeprecated(availableEntry)
                ? '- <strong class="red-text">' + strings('This plugin has been deprecated') + '</strong>'
                : !updateAvailable
                    ? ''
                    : '- **' + strings('Available Update') + ': ' + currentVersion + ' \u2192 ' + latest.version + '**'}`,
            contentType: 'text/markdown'
        }
    };
});
export default (registrar) => {
    const cmd = registrar.listen(`/${commandPrefix}/ibmcloud/plugin/show`, doGet('show'), opts);
    registrar.synonym(`/${commandPrefix}/ibmcloud/plugin/get`, doGet('get'), cmd, opts);
};
//# sourceMappingURL=get.js.map