var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { i18n } from '@kui-shell/core';
import { opts, commandPrefix } from '@kui-shell/plugin-ibmcloud/ks';
import semver from './semver';
import getRepoURL from './repo/url';
import getAvailablePlugins from './available';
import getInstalledPlugins from './installed';
const strings = i18n('plugin-ibmcloud/plugin');
function doLs(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const whichRepo = args.parsedOptions.r || args.parsedOptions.repo;
        const repoURL = whichRepo ? yield getRepoURL(args, whichRepo) : undefined;
        const [{ Plugins: allInstalled }, { plugins: available }] = yield Promise.all([
            getInstalledPlugins(args),
            getAvailablePlugins(args.tab, repoURL)
        ]);
        const rowData = Object.keys(allInstalled)
            .filter(installedName => available.find(({ name: availableName }) => availableName === installedName))
            .map(key => {
            const { Name: name, Aliases, Version } = allInstalled[key];
            const currentVersion = semver(Version);
            const availableEntry = available.find(_ => _.name === name);
            const latest = availableEntry && availableEntry.versions[availableEntry.versions.length - 1];
            const updateAvailable = latest && latest.version !== currentVersion;
            return { name, Aliases, currentVersion, latest, updateAvailable };
        });
        const allPluginsAreUpToDate = rowData.every(_ => !_.updateAvailable);
        const body = rowData.map(_ => ({
            name: _.name,
            onclick: `ibmcloud plugin get ${args.REPL.encodeComponent(_.name)}`,
            onclickSilence: true,
            attributes: [
                { key: strings('ALIASES'), value: _.Aliases ? _.Aliases.join(',') : '', outerCSS: 'hide-with-sidecar' },
                {
                    key: strings('STATUS'),
                    tag: 'badge',
                    value: !_.latest
                        ? strings('Unregistered Plugin')
                        : _.updateAvailable
                            ? strings('Update Available')
                            : strings('Ready'),
                    css: !_.latest ? 'gray-background' : _.updateAvailable ? 'yellow-background' : 'green-background'
                },
                { key: strings('VERSION'), value: _.currentVersion, outerCSS: '', css: '' }
            ].concat(allPluginsAreUpToDate
                ? []
                : [
                    {
                        key: strings('LATEST'),
                        value: _.updateAvailable ? _.latest.version : '',
                        outerCSS: 'hide-with-sidecar',
                        css: 'yellow-text'
                    }
                ])
        }));
        const header = {
            name: 'NAME',
            attributes: body[0].attributes.map(_ => ({ value: _.key, outerCSS: _.outerCSS }))
        };
        return {
            header,
            body
        };
    });
}
function doList(args) {
    args.command = args.command.replace(/ibmcloud\s+ks\s+clusters?\s+list/, 'ibmcloud ks cluster ls');
    const idx1 = args.argv.indexOf('ibmcloud');
    args.argv[idx1 + 3] = 'ls';
    const idx2 = args.argvNoOptions.indexOf('ibmcloud');
    args.argvNoOptions[idx2 + 3] = 'ls';
    return doLs(args);
}
export default (registrar) => {
    const cmd = registrar.listen(`/${commandPrefix}/ibmcloud/plugin/list`, doList, opts);
    registrar.synonym(`/${commandPrefix}/ibmcloud/plugin/ls`, doList, cmd, opts);
};
//# sourceMappingURL=list.js.map