var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { opts, commandPrefix } from '@kui-shell/plugin-ibmcloud/ks';
import { i18n } from '@kui-shell/core';
import getRepoURL from './url';
import semver from '../semver';
import getInstalledPlugins from '../installed';
import { getAvailablePluginsSafe } from '../available';
import { trafficLight } from '../../models/plugin';
import { isDeprecatedPattern, isDeprecated } from '../deprecated';
const strings = i18n('plugin-ibmcloud/plugin');
function doList(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const whichRepo = args.parsedOptions.r || args.parsedOptions.repo;
        const repoURL = whichRepo ? yield getRepoURL(args, whichRepo) : undefined;
        const [{ Plugins: installedPlugins }, { plugins: availablePlugins }] = yield Promise.all([
            getInstalledPlugins(args),
            getAvailablePluginsSafe(args.tab, repoURL)
        ]);
        const body = availablePlugins.map(availablePlugin => {
            const { name, description, versions } = availablePlugin;
            const isInstalled = installedPlugins[name] !== undefined;
            const installedVersion = isInstalled ? semver(installedPlugins[name].Version) : '';
            const latestVersion = versions[versions.length - 1].version;
            const updateAvailable = isInstalled && installedVersion !== latestVersion;
            const isItDeprecated = isDeprecated(availablePlugin);
            const descriptionForDisplay = description.replace(isDeprecatedPattern, '');
            const status = isItDeprecated
                ? 'Deprecated'
                : isInstalled
                    ? updateAvailable
                        ? 'Update Available'
                        : 'Ready'
                    : 'Available';
            return {
                name,
                onclick: `ibmcloud plugin repo-plugin ${args.REPL.encodeComponent(name)}${whichRepo ? ' -r ' + args.REPL.encodeComponent(whichRepo) : ''}`,
                onclickSilence: true,
                attributes: [
                    {
                        key: strings('STATUS'),
                        tag: 'badge',
                        value: strings(status),
                        css: trafficLight(status)
                    },
                    {
                        key: strings('DESCRIPTION'),
                        value: descriptionForDisplay,
                        outerCSS: 'hide-with-sidecar'
                    }
                ]
            };
        });
        const header = {
            name: 'NAME',
            attributes: body[0].attributes.map(_ => ({ value: _.key, outerCSS: _.outerCSS }))
        };
        return {
            header,
            body
        };
    });
}
export default (registrar) => {
    const cmd = registrar.listen(`/${commandPrefix}/ibmcloud/plugin/repo/available/list`, doList, opts);
    registrar.synonym(`/${commandPrefix}/ibmcloud/plugin/repo/available/ls`, doList, cmd, opts);
    registrar.listen(`/${commandPrefix}/ibmcloud/plugin/repo-plugins`, doList, opts);
    registrar.listen(`/${commandPrefix}/ibmcloud/plugin/repo-plugin`, (args) => {
        const pluginArg = args.REPL.encodeComponent(args.argvNoOptions[args.argvNoOptions.indexOf('repo-plugin') + 1]);
        const whichRepo = args.parsedOptions.r || args.parsedOptions.repo;
        const repoArg = whichRepo ? `-r ${args.REPL.encodeComponent(whichRepo)}` : '';
        const cmd = `${commandPrefix} ibmcloud plugin get ${pluginArg} ${repoArg}`;
        return args.REPL.qexec(cmd);
    }, opts);
};
//# sourceMappingURL=available.js.map