import { ResourceWithMetadata } from '@kui-shell/core';
import { WithRawData, WithSummary } from '@kui-shell/plugin-kubeui';
import { WithVersion } from '@kui-shell/plugin-ibmcloud/ks';
export interface SemVer {
    Major: number;
    Minor: number;
    Build: number;
}
interface Flag {
    Name: string;
    Description: string;
    HasValue: boolean;
    Hidden: boolean;
}
interface Namespace {
    ParentName: string;
    Name: string;
    Aliases: null | string[];
    Description: string;
    Stage: string;
}
interface Command {
    Namespace: string;
    Name: string;
    Alias: string;
    Aliases: string[];
    Description: string;
    Usage: string;
    Flags: null | Flag[];
    Hidden: boolean;
    Stage: string;
}
export interface IBMCloudInstalledPluginRaw {
    Name: string;
    Aliases: string[];
    Version: SemVer;
    MinCliVersion: SemVer;
    Namespaces: null | Namespace[];
    Commands: Command[];
    SDKVersion: {
        Major: 0;
        Minor: 2;
        Build: 0;
    };
    DelegateBashCompletion: boolean;
}
export interface InstalledPluginsRaw {
    Plugins: Record<string, IBMCloudInstalledPluginRaw>;
}
interface AvailablePluginVersion {
    version: string;
    updated: string;
    doc_url: string;
    min_cli_version: string;
    binaries: {
        platform: string;
        url: string;
        checksum: string;
    }[];
    api_versions: null | string[];
    release_notes_link: string;
}
export interface AvailablePluginRaw {
    name: string;
    aliases: null | string[];
    description: string;
    created: string;
    updated: string;
    company: string;
    homepage: string;
    authors: string[];
    versions: AvailablePluginVersion[];
    tags: null | string[];
}
export declare type PluginStatus = 'Ready' | 'Update Available' | 'Available' | 'Deprecated';
export declare function trafficLight(status: PluginStatus): string;
export declare type IBMCloudPlugin = ResourceWithMetadata<IBMCloudInstalledPluginRaw> & WithSummary & WithVersion<IBMCloudInstalledPluginRaw> & WithRawData<IBMCloudInstalledPluginRaw> & {
    apiVersion: any;
    kind: 'Plugin';
    isSimulacrum: true;
    spec: {
        updateAvailable: boolean;
        status: PluginStatus;
    };
};
export declare function isIBMCloudPlugin(resource: ResourceWithMetadata): resource is IBMCloudPlugin;
export declare function isIBMCloudPluginWithAvailableUpdates(resource: ResourceWithMetadata): resource is IBMCloudPlugin;
export declare function isIBMCloudPluginWithCommands(resource: ResourceWithMetadata): resource is IBMCloudPlugin;
export declare type IBMCloudPluginCommand = ResourceWithMetadata<IBMCloudInstalledPluginRaw> & WithSummary & {
    apiVersion: any;
    kind: 'Command';
    isSimulacrum: true;
    spec: {
        usage: string;
    };
};
export declare function isIBMCloudPluginCommand(resource: ResourceWithMetadata): resource is IBMCloudPluginCommand;
export {};
