import Debug from 'debug';
import fqn from '../fqn';
const debug = Debug('plugin-kubeui/controller/watch/poller');
const sleepTime = 1000;
export default function pollUntil404(apiVersion, kind, name, namespace, offline, { REPL }) {
    let done = false;
    let currentTimeout;
    const poll = (iter = 0) => {
        const cmd = `kubectl get ${fqn(apiVersion, kind, name, namespace)} -o custom-columns=KIND:.kind`;
        debug('poll for termination', cmd);
        REPL.qexec(cmd)
            .then(() => {
            if (!done) {
                const thisSleepTime = iter < 5 ? sleepTime : iter < 10 ? sleepTime * 2 : iter < 20 ? sleepTime * 4 : sleepTime * 10;
                currentTimeout = setTimeout(() => poll(iter + 1), thisSleepTime);
            }
        })
            .catch((err) => {
            offline(name);
            if (err.code !== 404) {
                console.error('unexpected error in pollUntil404', err);
            }
        });
    };
    poll();
    return {
        abort: () => {
            done = true;
            if (currentTimeout) {
                clearTimeout(currentTimeout);
            }
        }
    };
}
//# sourceMappingURL=poller.js.map