var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Debug from 'debug';
import { i18n } from '@kui-shell/core';
import { isCustomResourceDefinition } from '../../model/resource';
import { command } from './show-crd-managed-resources';
const strings = i18n('plugin-kubeui');
const debug = Debug('plugin-kubeui/view/modes/crd-summary');
function content(tab, crd) {
    return __awaiter(this, void 0, void 0, function* () {
        const { group, version, scope } = crd.spec;
        const kind = crd.spec.names.kind;
        const scopeObj = scope ? { scope } : {};
        const groupObj = group ? { group } : {};
        const versionObj = version ? { version } : {};
        const kindObj = kind ? { kind } : {};
        const baseResponse = Object.assign({}, scopeObj, groupObj, versionObj, kindObj);
        try {
            const [{ safeDump }, { body: resources }] = yield Promise.all([
                import('js-yaml'),
                tab.REPL.qexec(`${command(tab, crd)} -o custom-columns=NAME:.metadata.name`)
            ]);
            const countObj = { 'resource count': resources.length };
            return {
                content: safeDump(Object.assign(baseResponse, countObj)),
                contentType: 'yaml'
            };
        }
        catch (err) {
            debug('error trying to determine resource count for crd', err);
            const safeDump = yield import('js-yaml');
            return {
                content: safeDump(baseResponse),
                contentType: 'yaml'
            };
        }
    });
}
const mode = {
    when: isCustomResourceDefinition,
    mode: {
        mode: 'summary',
        label: strings('summary'),
        content,
        priority: 10
    }
};
export default mode;
//# sourceMappingURL=crd-summary.js.map