"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = require("debug");
const debug = debug_1.default('plugins/tekton/preload');
debug('loading');
const path_1 = require("path");
const core_1 = require("@kui-shell/core");
const resource_1 = require("./model/resource");
function either(...filters) {
    return (resource) => filters.some(filter => filter(resource));
}
function registerModes(registrar) {
    return __awaiter(this, void 0, void 0, function* () {
        const [flowMode, traceMode, logsMode] = yield Promise.all([
            Promise.resolve().then(() => require('./model/modes/flow')),
            Promise.resolve().then(() => require('./model/modes/trace')),
            Promise.resolve().then(() => require('./model/modes/logs'))
        ]);
        const flowSpec = {
            mode: flowMode.default,
            when: either(resource_1.isPipeline, resource_1.isPipelineRun, resource_1.isTask)
        };
        const traceSpec = {
            mode: traceMode.default,
            when: resource_1.isPipelineRun
        };
        const logsSpec = {
            mode: logsMode.default,
            when: resource_1.isPipelineRun
        };
        registrar.registerModes(flowSpec, traceSpec, logsSpec);
    });
}
exports.default = (registrar) => {
    if (!core_1.inBrowser()) {
        const requireFunc = typeof __webpack_require__ === 'function' ? __non_webpack_require__ : require;
        const specialPath = path_1.join(path_1.dirname(requireFunc.resolve('@kui-shell/plugin-tekton/package.json')), 'samples/@demos');
        core_1.augmentModuleLoadPath(specialPath, { prefix: '@demos/tekton', command: 'tekton flow' });
    }
    if (!core_1.isHeadless()) {
        return registerModes(registrar);
    }
};
debug('finished loading');
//# sourceMappingURL=preload.js.map