var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Debug from 'debug';
const debug = Debug('plugins/tekton/preload');
debug('loading');
import { dirname, join } from 'path';
import { isHeadless, inBrowser, augmentModuleLoadPath } from '@kui-shell/core';
import { isPipeline, isPipelineRun, isTask } from './model/resource';
function either(...filters) {
    return (resource) => filters.some(filter => filter(resource));
}
function registerModes(registrar) {
    return __awaiter(this, void 0, void 0, function* () {
        const [flowMode, traceMode, logsMode] = yield Promise.all([
            import('./model/modes/flow'),
            import('./model/modes/trace'),
            import('./model/modes/logs')
        ]);
        const flowSpec = {
            mode: flowMode.default,
            when: either(isPipeline, isPipelineRun, isTask)
        };
        const traceSpec = {
            mode: traceMode.default,
            when: isPipelineRun
        };
        const logsSpec = {
            mode: logsMode.default,
            when: isPipelineRun
        };
        registrar.registerModes(flowSpec, traceSpec, logsSpec);
    });
}
export default (registrar) => {
    if (!inBrowser()) {
        const requireFunc = typeof __webpack_require__ === 'function' ? __non_webpack_require__ : require;
        const specialPath = join(dirname(requireFunc.resolve('@kui-shell/plugin-tekton/package.json')), 'samples/@demos');
        augmentModuleLoadPath(specialPath, { prefix: '@demos/tekton', command: 'tekton flow' });
    }
    if (!isHeadless()) {
        return registerModes(registrar);
    }
};
debug('finished loading');
//# sourceMappingURL=preload.js.map